@@ -1,58 +1,31 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
 package com.openexchange.caldav;
 
-import static com.openexchange.chronos.common.CalendarUtils.addExtendedProperty;
+import static com.openexchange.chronos.common.CalendarUtils.*;
 import static com.openexchange.chronos.common.CalendarUtils.find;
 import static com.openexchange.chronos.common.CalendarUtils.getEventID;
 import static com.openexchange.chronos.common.CalendarUtils.isGroupScheduled;
+import static com.openexchange.chronos.common.CalendarUtils.isOpaqueTransparency;
 import static com.openexchange.chronos.common.CalendarUtils.isOrganizer;
 import static com.openexchange.chronos.common.CalendarUtils.isSeriesException;
 import static com.openexchange.chronos.common.CalendarUtils.isSeriesMaster;
@@ -181,7 +154,7 @@ public class EventPatches {
     public static ICalParameters applyIgnoredProperties(EventResource resource, ICalParameters parameters) {
         if (null != parameters) {
             DAVUserAgent userAgent = resource.getUserAgent();
-            if (false == DAVUserAgent.EM_CLIENT.equals(userAgent)) {
+            if (false == DAVUserAgent.EM_CLIENT.equals(userAgent) && false == DAVUserAgent.EM_CLIENT_FOR_APPSUITE.equals(userAgent)) {
                 /*
                  * forcibly ignore X-MICROSOFT-CDO-ALLDAYEVENT and X-MICROSOFT-CDO-BUSYSTATUS for clients other than em client
                  */
@@ -400,8 +373,8 @@ public class EventPatches {
                  */
                 adjustMozillaLastAcknowledged(importedEvent, importedSeriesMaster, calendar);
             }
-            if (DAVUserAgent.THUNDERBIRD_LIGHTNING.equals(resource.getUserAgent()) || DAVUserAgent.EM_CLIENT.equals(resource.getUserAgent())) {
-
+            if (DAVUserAgent.THUNDERBIRD_LIGHTNING.equals(resource.getUserAgent()) || DAVUserAgent.EM_CLIENT.equals(resource.getUserAgent())||
+                DAVUserAgent.EM_CLIENT_FOR_APPSUITE.equals(resource.getUserAgent())) {
                 /*
                  * handle snoozing via X-MOZ-SNOOZE and X-MOZ-SNOOZE-TIME-...
                  */
@@ -760,7 +733,7 @@ public class EventPatches {
          * @param importedChangeExceptions The imported change exceptions as supplied by the client
          */
         private void restoreAttendeeForOrganizer(EventResource resource, Event importedEvent, List<Event> importedChangeExceptions) {
-            if (false == resource.exists() || null == importedEvent || false == DAVUserAgent.MAC_CALENDAR.equals(resource.getUserAgent()) || 
+            if (false == resource.exists() || null == importedEvent || false == DAVUserAgent.MAC_CALENDAR.equals(resource.getUserAgent()) ||
                 false == isGroupScheduled(importedEvent) || false == isOrganizer(resource.getEvent(), resource.getFactory().getUser().getId())) {
                 return; // not applicable
             }
@@ -869,7 +842,7 @@ public class EventPatches {
             if (!resource.exists()  || !AUTO_ORGANIZER_AGENTS.contains(resource.getUserAgent()) || !PublicType.getInstance().equals(resource.getParent().getFolder().getType())) {
                 return;
             }
-            
+
             Event orig = resource.getEvent();
             removeOrganizer(importedEvent, orig);
             if (importedChangeExceptions != null) {
@@ -891,7 +864,7 @@ public class EventPatches {
                 }
             }
         }
-        
+
         /**
          * Restores the participant status of attendees on incoming event patches if the client
          * set the status to {@link ParticipationStatus#NEEDS_ACTION}
@@ -972,6 +945,95 @@ public class EventPatches {
             }.execute(factory.getSession());
         }
 
+        /**
+         * Restores an event's transparency back to its original value in case the participation status of the calendar user's attendee
+         * was also changed along with the update (bug 23610).
+         *
+         * @param resource The event resource
+         * @param importedEvent The imported series master event as supplied by the client
+         * @param importedChangeExceptions The imported change exceptions as supplied by the client
+         */
+        private void restoreEventTransparency(EventResource resource, Event importedEvent, List<Event> importedChangeExceptions) {
+            if (false == resource.exists() || null == importedEvent || false == isGroupScheduled(importedEvent) ||
+                isOrganizer(resource.getEvent(), resource.getFactory().getUser().getId())) {
+                return; // not applicable
+            }
+            try {
+                int calendarUserId = resource.getParent().getCalendarUser().getId();
+                new CalendarAccessOperation<Void>(factory) {
+
+                    @Override
+                    protected Void perform(IDBasedCalendarAccess access) throws OXException {
+                        /*
+                         * restore transparency in single event or series master
+                         */
+                        EventID eventID = getEventID(resource.getEvent());
+                        restoreEventTransparency(access, calendarUserId, eventID, importedEvent);
+                        /*
+                         * restore transparency in change exceptions
+                         */
+                        if (null != importedChangeExceptions) {
+                            for (Event importedChangeException : importedChangeExceptions) {
+                                eventID = new EventID(eventID.getFolderID(), eventID.getObjectID(), importedChangeException.getRecurrenceId());
+                                restoreEventTransparency(access, calendarUserId, eventID, importedEvent);
+                            }
+                        }
+                        return null;
+                    }
+                }.execute(factory.getSession());
+            } catch (OXException e) {
+                LOG.warn("Error restoring participation status in organizer's attendee", e);
+            }
+        }
+
+        private Event optEvent(IDBasedCalendarAccess access, EventID eventID) {
+            try {
+                return access.getEvent(eventID);
+            } catch (OXException e) {
+                LOG.debug("Unable to get event with id {}", eventID, e);
+                return null;
+            }
+        }
+
+        /**
+         * Restores an event's transparency back to its original value in case the participation status of the calendar user's attendee
+         * was also changed along with the update, and the underlying event represents an attendee scheduling resource.
+         *
+         * @param access A reference to the calendar access
+         * @param calendarUserId The identifier of the actual calendar user id
+         * @param eventID The identifier of the original event to check the imported event against
+         * @param importedEvent The imported event
+         */
+        private void restoreEventTransparency(IDBasedCalendarAccess access, int calendarUserId, EventID eventID, Event importedEvent) throws OXException {
+            /*
+             * check if transparency has changed
+             */
+            Event originalEvent = optEvent(access, eventID);
+            if (null == originalEvent || isOpaqueTransparency(importedEvent) == isOpaqueTransparency(originalEvent) || 
+                false == isAttendeeSchedulingResource(originalEvent, calendarUserId)) {
+                return;
+            }
+            /*
+             * check if participation status of user attendee has changed, too
+             */
+            Attendee originalAttendee = find(originalEvent.getAttendees(), calendarUserId);
+            if (null == originalAttendee) {
+                return;
+            }
+            EntityResolver entityResolver = factory.requireService(CalendarUtilities.class).getEntityResolver(factory.getContext().getContextId());
+            entityResolver.prepare(importedEvent.getAttendees(), new int[] { calendarUserId });
+            Attendee updatedAttendee = find(importedEvent.getAttendees(), calendarUserId);
+            if (null == updatedAttendee || false == matches(updatedAttendee, originalAttendee)) {
+                return;
+            }
+            if (null != originalAttendee.getPartStat() && false == originalAttendee.getPartStat().matches(updatedAttendee.getPartStat())) {
+                /*
+                 * participation status actively changed, so ignore implicit transparency change
+                 */
+                importedEvent.setTransp(originalEvent.getTransp());
+            }
+        }
+
         /**
          * Applies all known patches to an event after importing.
          *
@@ -1002,6 +1064,7 @@ public class EventPatches {
                 stripExtendedPropertiesFromAttendeeSchedulingResource(resource, importedEvent);
                 removeOrganizerAttendee(resource, importedEvent, importedChangeExceptions);
                 restoreParticipantStatus(resource, importedEvent);
+                restoreEventTransparency(resource, importedEvent, importedChangeExceptions);
             }
             if (null != importedChangeExceptions && 0 < importedChangeExceptions.size()) {
                 /*
