@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -90,6 +62,7 @@ import com.openexchange.login.Interface;
 import com.openexchange.oauth.provider.resourceserver.scope.AbstractScopeProvider;
 import com.openexchange.oauth.provider.resourceserver.scope.OAuthScopeProvider;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.osgi.service.http.HttpServices;
 import com.openexchange.resource.ResourceService;
 import com.openexchange.session.Session;
 import com.openexchange.user.User;
@@ -114,6 +87,8 @@ public class CaldavActivator extends HousekeepingActivator {
     private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(CaldavActivator.class);
 
     private OSGiPropertyMixin mixin;
+    private String httpAliasCalDAV;
+    private String httpAliasDevNull;
 
     /**
      * Initializes a new {@link CaldavActivator}.
@@ -138,9 +113,11 @@ public class CaldavActivator extends HousekeepingActivator {
             final HttpService httpService = getService(HttpService.class);
 
             ConfigViewFactory configViewFactory = getServiceSafe(ConfigViewFactory.class);
-            httpService.registerServlet(getInternalPath(configViewFactory, SERVLET_PATH), new CalDAV(performer), null, null);
+            httpAliasCalDAV = getInternalPath(configViewFactory, SERVLET_PATH);
+            httpService.registerServlet(httpAliasCalDAV, new CalDAV(performer), null, null);
             httpService.registerServlet("/.well-known/caldav", new WellKnownServlet(getExternalPath(configViewFactory, SERVLET_PATH), Interface.CALDAV), null, null);
-            httpService.registerServlet(getInternalPath(configViewFactory, NULL_PATH), new DevNullServlet(), null, null);
+            httpAliasDevNull = getInternalPath(configViewFactory, NULL_PATH);
+            httpService.registerServlet(httpAliasDevNull, new DevNullServlet(), null, null);
 
             final OSGiPropertyMixin mixin = new OSGiPropertyMixin(context, performer);
             performer.setGlobalMixins(mixin);
@@ -234,14 +211,21 @@ public class CaldavActivator extends HousekeepingActivator {
     protected synchronized void stopBundle() throws Exception {
         final HttpService httpService = getService(HttpService.class);
         if (null != httpService) {
-            ConfigViewFactory configViewFactory = getService(ConfigViewFactory.class);
-            httpService.unregister(getInternalPath(configViewFactory, SERVLET_PATH));
-            httpService.unregister(getInternalPath(configViewFactory, NULL_PATH));
+            String alias = this.httpAliasCalDAV;
+            if (alias != null) {
+                this.httpAliasCalDAV = null;
+                HttpServices.unregister(alias, httpService);
+            }
+            alias = this.httpAliasDevNull;
+            if (alias != null) {
+                this.httpAliasDevNull = null;
+                HttpServices.unregister(alias, httpService);
+            }
         }
         final OSGiPropertyMixin mixin = this.mixin;
         if (null != mixin) {
-            mixin.close();
             this.mixin = null;
+            mixin.close();
         }
         super.stopBundle();
     }
