@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -54,12 +26,12 @@ import static com.openexchange.chronos.provider.basic.CommonCalendarConfiguratio
 import static com.openexchange.chronos.provider.basic.CommonCalendarConfigurationFields.URI;
 import static com.openexchange.dav.DAVProtocol.protocolException;
 import static com.openexchange.folderstorage.CalendarFolderConverter.CALENDAR_CONFIG_FIELD;
+import static java.util.regex.Matcher.quoteReplacement;
 import java.io.InputStream;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Date;
 import java.util.List;
-import java.util.Locale;
 import java.util.Map;
 import java.util.concurrent.TimeUnit;
 import javax.servlet.http.HttpServletResponse;
@@ -260,16 +232,29 @@ public abstract class CalDAVFolderCollection<T> extends FolderCollection<T> impl
 
     @Override
     public String getDisplayName() throws WebdavProtocolException {
-        Locale locale = factory.getUser().getLocale();
-        String name = locale != null ? folder.getLocalizedName(locale) : folder.getName();
-        String ownerName = getOwnerName();
-
-        if (PrivateType.getInstance().equals(this.folder.getType()) && folder.isDefault()) {
-            return getStandardFolderDisplayNameTemplate().replaceAll("\\[foldername\\]", name).replaceAll("\\[owner\\]", ownerName);
-        } else if (SharedType.getInstance().equals(this.folder.getType())) {
-            return getSharedFolderDisplayNameTemplate().replaceAll("\\[foldername\\]", name).replaceAll("\\[owner\\]", ownerName);
+        /*
+         * derive localized folder name
+         */
+        String name = folder.getLocalizedName(factory.getUser().getLocale());
+        if (Strings.isEmpty(name)) {
+            name = folder.getName();
+            if (Strings.isEmpty(name)) {
+                LOG.warn("No display name available for folder {}, using generic fallback.", folder.getID());
+                name = "Folder " + folder.getID();
+            }
+        }
+        /*
+         * adjust display name for specific folder type if needed
+         */
+        if (SharedType.getInstance().equals(folder.getType()) || PrivateType.getInstance().equals(folder.getType()) && folder.isDefault()) {
+            String ownerName = getOwnerName();
+            if (Strings.isEmpty(ownerName)) {
+                LOG.warn("No owner name available for folder {}, falling back to folder name as-is.", folder.getID());
+            } else {
+                String template = SharedType.getInstance().equals(folder.getType()) ? getSharedFolderDisplayNameTemplate() : getStandardFolderDisplayNameTemplate();
+                name = template.replaceAll("\\[foldername\\]", quoteReplacement(name)).replaceAll("\\[owner\\]", quoteReplacement(ownerName));
+            }
         }
-
         return name;
     }
 
