@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -58,6 +30,7 @@ import java.util.Date;
 import java.util.List;
 import javax.servlet.http.HttpServletResponse;
 import org.dmfs.rfc5545.DateTime;
+import com.google.common.escape.Escaper;
 import com.google.common.xml.XmlEscapers;
 import com.openexchange.caldav.CalDAVImport;
 import com.openexchange.caldav.CaldavProtocol;
@@ -202,7 +175,7 @@ public class EventResource extends DAVObjectResource<Event> {
         if (null == object || false == object.containsSequence()) {
             return null;
         }
-        return '"' + String.valueOf(object.getSequence()) + '"';
+        return String.valueOf(object.getSequence());
     }
 
     /**
@@ -347,14 +320,15 @@ public class EventResource extends DAVObjectResource<Event> {
                     calendarUser = object.getModifiedBy();
                     timestamp = object.getLastModified();
                 }
+                Escaper escaper = XmlEscapers.xmlContentEscaper();
                 StringBuilder stringBuilder = new StringBuilder();
                 if (null != calendarUser) {
-                    stringBuilder.append("<D:href>").append(calendarUser.getUri()).append("</D:href>");
+                    stringBuilder.append("<D:href>").append(escaper.escape(calendarUser.getUri())).append("</D:href>");
                     if (CalendarUtils.isInternal(calendarUser, CalendarUserType.INDIVIDUAL)) {
                         try {
                             User user = factory.getService(UserService.class).getUser(calendarUser.getEntity(), factory.getContext());
-                            stringBuilder.append("<CS:first-name>").append(user.getGivenName()).append("</CS:first-name>")
-                                .append("<CS:last-name>").append(user.getSurname()).append("</CS:last-name>");
+                            stringBuilder.append("<CS:first-name>").append(escaper.escape(user.getGivenName())).append("</CS:first-name>")
+                                .append("<CS:last-name>").append(escaper.escape(user.getSurname())).append("</CS:last-name>");
                         } catch (OXException e) {
                             LOG.warn("error resolving user '{}'", calendarUser, e);
                         }
@@ -364,7 +338,7 @@ public class EventResource extends DAVObjectResource<Event> {
                     stringBuilder.append("<CS:dtstamp>").append(Tools.formatAsUTC(timestamp)).append("</CS:dtstamp>");
                 }
                 property.setXML(true);
-                property.setValue(XmlEscapers.xmlContentEscaper().escape(stringBuilder.toString()));
+                property.setValue(stringBuilder.toString());
             }
             return property;
         }
