@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -81,7 +53,7 @@ import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.Type;
 import com.openexchange.folderstorage.UserizedFolder;
-import com.openexchange.folderstorage.database.contentType.ContactContentType;
+import com.openexchange.folderstorage.database.contentType.ContactsContentType;
 import com.openexchange.folderstorage.type.PrivateType;
 import com.openexchange.folderstorage.type.PublicType;
 import com.openexchange.folderstorage.type.SharedType;
@@ -204,22 +176,13 @@ public class GroupwareCarddavFactory extends DAVFactory {
     }
 
     /**
-     * Sets the next sync token for the current user to <code>"0"</code>,
-     * enforcing the next sync status report to contain all changes
-     * independently of the sync token supplied by the client, thus emulating
-     * some kind of slow-sync this way.
-     */
-    public void overrideNextSyncToken() {
-        this.setOverrideNextSyncToken("0");
-    }
-
-    /**
-     * Sets the next sync token for the current user to the supplied value.
+     * Sets the next sync token for the current user in a certain collection to the supplied value.
      *
-     * @param value The overridden value
+     * @param folderId The identifier of the folder to override the sync-token in, or <code>null</code> to override it generally
+     * @param value The overridden value, or <code>null</code> to remove a previously overridden value
      */
-    public void setOverrideNextSyncToken(String value) {
-        String attributeName = getOverrideNextSyncTokenAttributeName();
+    public void setOverrideNextSyncToken(String folderId, String value) {
+        String attributeName = getOverrideNextSyncTokenAttributeName(folderId);
         try {
             getService(UserService.class).setAttribute(attributeName, value, getUser().getId(), getContext());
         } catch (OXException e) {
@@ -230,11 +193,12 @@ public class GroupwareCarddavFactory extends DAVFactory {
     /**
      * Gets a value indicating the overridden sync token for the current user if defined
      *
+     * @param folderId The identifier of the targeted folder, or <code>null</code> to check for a globally overridden token
      * @return The value of the overridden sync-token, or <code>null</code> if not set
      */
-    public String getOverrideNextSyncToken() {
+    public String getOverrideNextSyncToken(String folderId) {
         User user = getUser();
-        String attributeName = getOverrideNextSyncTokenAttributeName();
+        String attributeName = getOverrideNextSyncTokenAttributeName(folderId);
         Map<String, String> attributes = user.getAttributes();
         if (null != attributes) {
             /*
@@ -262,9 +226,16 @@ public class GroupwareCarddavFactory extends DAVFactory {
         return null;
     }
 
-    private String getOverrideNextSyncTokenAttributeName() {
+    private String getOverrideNextSyncTokenAttributeName(String folderId) {
+        StringBuilder stringBuilder = new StringBuilder(OVERRIDE_NEXT_SYNC_TOKEN_PROPERTY);
         String userAgent = (String) getSession().getParameter("user-agent");
-        return null != userAgent ? OVERRIDE_NEXT_SYNC_TOKEN_PROPERTY + userAgent.hashCode() : OVERRIDE_NEXT_SYNC_TOKEN_PROPERTY;
+        if (null != userAgent) {
+            stringBuilder.append('.').append(userAgent.hashCode());
+        }
+        if (null != folderId) {
+            stringBuilder.append('.').append(folderId);
+        }
+        return stringBuilder.toString();
     }
 
     public static final class State {
@@ -296,7 +267,7 @@ public class GroupwareCarddavFactory extends DAVFactory {
         public UserizedFolder getDefaultFolder() throws OXException {
             if (null == defaultFolder) {
                 defaultFolder = factory.getFolderService().getDefaultFolder(
-                    factory.getUser(), getTreeID(), ContactContentType.getInstance(), factory.getSession(), null);
+                    factory.getUser(), getTreeID(), ContactsContentType.getInstance(), factory.getSession(), null);
             }
             return defaultFolder;
         }
@@ -386,7 +357,7 @@ public class GroupwareCarddavFactory extends DAVFactory {
         private List<UserizedFolder> getVisibleFolders(Type type) throws OXException {
             List<UserizedFolder> folders = new ArrayList<UserizedFolder>();
             FolderService folderService = factory.getFolderService();
-            FolderResponse<UserizedFolder[]> visibleFoldersResponse = folderService.getVisibleFolders(FolderStorage.REAL_TREE_ID, ContactContentType.getInstance(), type, true, this.factory.getSession(), null);
+            FolderResponse<UserizedFolder[]> visibleFoldersResponse = folderService.getVisibleFolders(FolderStorage.REAL_TREE_ID, ContactsContentType.getInstance(), type, true, this.factory.getSession(), null);
             UserizedFolder[] response = visibleFoldersResponse.getResponse();
             for (UserizedFolder folder : response) {
                 if (Permission.READ_OWN_OBJECTS < folder.getOwnPermission().getReadPermission() && false == isBlacklisted(folder)) {
@@ -405,11 +376,11 @@ public class GroupwareCarddavFactory extends DAVFactory {
         public List<UserizedFolder> getDeletedFolders(Date since) throws OXException {
             List<UserizedFolder> folders = new ArrayList<UserizedFolder>();
             FolderService folderService = factory.getFolderService();
-            FolderResponse<UserizedFolder[][]> updatedFoldersResponse = folderService.getUpdates(FolderStorage.REAL_TREE_ID, since, false, new ContentType[] { ContactContentType.getInstance() }, this.factory.getSession(), null);
+            FolderResponse<UserizedFolder[][]> updatedFoldersResponse = folderService.getUpdates(FolderStorage.REAL_TREE_ID, since, false, new ContentType[] { ContactsContentType.getInstance() }, this.factory.getSession(), null);
             UserizedFolder[][] response = updatedFoldersResponse.getResponse();
             if (2 <= response.length && null != response[1] && 0 < response[1].length) {
                 for (UserizedFolder folder : response[1]) {
-                    if (Permission.READ_OWN_OBJECTS < folder.getOwnPermission().getReadPermission() && false == isBlacklisted(folder) && ContactContentType.getInstance().equals(folder.getContentType())) {
+                    if (Permission.READ_OWN_OBJECTS < folder.getOwnPermission().getReadPermission() && false == isBlacklisted(folder) && ContactsContentType.getInstance().equals(folder.getContentType())) {
                         folders.add(folder);
                     }
                 }
