@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -63,6 +35,7 @@ import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.config.lean.LeanConfigurationService;
 import com.openexchange.contact.ContactService;
 import com.openexchange.contact.similarity.ContactSimilarityService;
+import com.openexchange.contact.storage.ContactTombstoneStorage;
 import com.openexchange.contact.vcard.VCardService;
 import com.openexchange.contact.vcard.storage.VCardStorageFactory;
 import com.openexchange.dav.DAVServlet;
@@ -75,6 +48,7 @@ import com.openexchange.login.Interface;
 import com.openexchange.oauth.provider.resourceserver.scope.AbstractScopeProvider;
 import com.openexchange.oauth.provider.resourceserver.scope.OAuthScopeProvider;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.osgi.service.http.HttpServices;
 import com.openexchange.resource.ResourceService;
 import com.openexchange.user.UserService;
 import com.openexchange.webdav.protocol.osgi.OSGiPropertyMixin;
@@ -90,6 +64,9 @@ public class CarddavActivator extends HousekeepingActivator {
 
     private OSGiPropertyMixin mixin;
 
+    private String httpAliasCardDAV;
+    private String httpAliasPhotos;
+
     /**
      * Initializes a new {@link CarddavActivator}.
      */
@@ -105,6 +82,11 @@ public class CarddavActivator extends HousekeepingActivator {
         };
     }
 
+    @Override
+    protected Class<?>[] getOptionalServices() {
+        return new Class[] { ContactTombstoneStorage.class };
+    }
+
     @Override
     protected synchronized void startBundle() throws Exception {
         try {
@@ -120,7 +102,8 @@ public class CarddavActivator extends HousekeepingActivator {
              * register CardDAV servlet & WebDAV path
              */
             ConfigViewFactory configViewFactory = getServiceSafe(ConfigViewFactory.class);
-            getService(HttpService.class).registerServlet(getInternalPath(configViewFactory, "/carddav"), new CardDAV(performer), null, null);
+            httpAliasCardDAV = getInternalPath(configViewFactory, "/carddav");
+            getService(HttpService.class).registerServlet(httpAliasCardDAV, new CardDAV(performer), null, null);
             getService(HttpService.class).registerServlet("/.well-known/carddav", new WellKnownServlet(getExternalPath(configViewFactory, "/carddav"), Interface.CARDDAV), null, null);
             registerService(OAuthScopeProvider.class, new AbstractScopeProvider(Tools.OAUTH_SCOPE, OAuthStrings.SYNC_CONTACTS) {
 
@@ -132,7 +115,8 @@ public class CarddavActivator extends HousekeepingActivator {
             /*
              * register Photo performer for referenced contact images in vCards
              */
-            getService(HttpService.class).registerServlet(getInternalPath(configViewFactory, "/photos"), new DAVServlet(new PhotoPerformer(this), Interface.CARDDAV), null, null);
+            httpAliasPhotos = getInternalPath(configViewFactory, "/photos");
+            getService(HttpService.class).registerServlet(httpAliasPhotos, new DAVServlet(new PhotoPerformer(this), Interface.CARDDAV), null, null);
             /*
              * track optional services
              */
@@ -162,9 +146,16 @@ public class CarddavActivator extends HousekeepingActivator {
          */
         HttpService httpService = getService(HttpService.class);
         if (null != httpService) {
-            ConfigViewFactory configViewFactory = getServiceSafe(ConfigViewFactory.class);
-            String carddavPath = getInternalPath(configViewFactory, "/carddav");
-            httpService.unregister(carddavPath);
+            String alias = httpAliasCardDAV;
+            if (alias != null) {
+                httpAliasCardDAV = null;
+                HttpServices.unregister(alias, httpService);
+            }
+            alias = httpAliasPhotos;
+            if (alias != null) {
+                httpAliasPhotos = null;
+                HttpServices.unregister(alias, httpService);
+            }
         }
         super.stopBundle();
     }
