@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -133,11 +105,11 @@ public class CardDAVCollection extends FolderCollection<Contact> {
         super(factory, url, folder);
         this.factory = factory;
         includeProperties(
-            new CurrentUserPrivilegeSet(folder.getOwnPermission()), 
-            new SupportedReportSet(), 
-            new MaxResourceSize(factory), 
-            new MaxImageSize(factory), 
-            new SupportedAddressData(), 
+            new CurrentUserPrivilegeSet(folder.getOwnPermission()),
+            new SupportedReportSet(),
+            new MaxResourceSize(factory),
+            new MaxImageSize(factory),
+            new SupportedAddressData(),
             new BulkRequests(factory)
         );
     }
@@ -297,14 +269,14 @@ public class CardDAVCollection extends FolderCollection<Contact> {
 
     /**
      * Gets a value indicating whether synchronization of distribution lists is enabled for the used client or not.
-     * 
+     *
      * @return <code>true</code> if distribution lists can be synchronized with the used client, <code>false</code>, otherwise
      */
     public boolean isSyncDistributionLists() {
         DAVUserAgent davUserAgent = getUserAgent();
-        return davUserAgent.equals(DAVUserAgent.EM_CLIENT) || 
+        return davUserAgent.equals(DAVUserAgent.EM_CLIENT) ||
             davUserAgent.equals(DAVUserAgent.EM_CLIENT_FOR_APPSUITE) ||
-            davUserAgent.equals(DAVUserAgent.OUTLOOK_CALDAV_SYNCHRONIZER) 
+            davUserAgent.equals(DAVUserAgent.OUTLOOK_CALDAV_SYNCHRONIZER)
             ;
     }
 
@@ -545,11 +517,11 @@ public class CardDAVCollection extends FolderCollection<Contact> {
             /*
              * check for overridden sync-token for this client
              */
-            String overrrideSyncToken = factory.getOverrideNextSyncToken();
+            String overrrideSyncToken = factory.getOverrideNextSyncToken(folder.getID());
             if (null != overrrideSyncToken && 0 < overrrideSyncToken.length()) {
-                factory.setOverrideNextSyncToken(null);
+                factory.setOverrideNextSyncToken(folder.getID(), null);
                 token = overrrideSyncToken;
-                LOG.debug("Overriding sync token to '{}' for user '{}'.", token, this.factory.getUser());
+                LOG.debug("Overriding sync token to '{}' for collection '{}'.", token, getUrl());
             }
         }
         return super.getSyncStatus(token, limit);
@@ -560,11 +532,11 @@ public class CardDAVCollection extends FolderCollection<Contact> {
         /*
          * check for overridden sync-token for this client
          */
-        String overrrideSyncToken = factory.getOverrideNextSyncToken();
+        String overrrideSyncToken = factory.getOverrideNextSyncToken(folder.getID());
         if (null != overrrideSyncToken && 0 < overrrideSyncToken.length()) {
-            factory.setOverrideNextSyncToken(null);
+            factory.setOverrideNextSyncToken(folder.getID(), null);
             String value = "http://www.open-xchange.com/ctags/" + folder.getID() + "-" + overrrideSyncToken;
-            LOG.debug("Overriding CTag property to '{}' for user '{}'.", value, factory.getUser());
+            LOG.debug("Overriding CTag property to '{}' for collection '{}'.", value, getUrl());
             return value;
         }
         return super.getCTag();
