@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -72,6 +44,7 @@ import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.config.lean.LeanConfigurationService;
 import com.openexchange.contact.ContactFieldOperand;
 import com.openexchange.contact.ContactService;
+import com.openexchange.contact.storage.ContactTombstoneStorage;
 import com.openexchange.contact.vcard.DistributionListMode;
 import com.openexchange.contact.vcard.VCardExport;
 import com.openexchange.contact.vcard.VCardImport;
@@ -317,11 +290,19 @@ public class ContactResource extends CommonResource<Contact> {
                     contact.setFilename(extractedUID);
                 }
             }
-            /*
-             * set initial parent folder to the default contacts folder in case of an iOS client
-             */
             contact.setContextId(session.getContextId());
-            String parentFolderID = DAVUserAgent.IOS.equals(getUserAgent()) ? factory.getState().getDefaultFolder().getID() : String.valueOf(getId(parent));
+            String parentFolderID = parent.getFolder().getID();
+            if (DAVUserAgent.IOS.equals(getUserAgent()) && false == parentFolderID.equals(factory.getState().getDefaultFolder().getID())) {
+                /*
+                 * for iOS, set initial parent to the default contacts folder & insert tombstone record for automatic cleanup during next sync
+                 */
+                ContactTombstoneStorage tombstoneStorage = factory.getOptionalService(ContactTombstoneStorage.class);
+                if (null != tombstoneStorage && tombstoneStorage.supports(session, parentFolderID)) {
+                    LOG.debug("{}: Re-routing contact creation to default folder for iOS client, inserting tombstone in targeted folder for client recovery.", getUrl());
+                    tombstoneStorage.insertTombstone(session, parentFolderID, contact);
+                }
+                parentFolderID = factory.getState().getDefaultFolder().getID();
+            }
             if (contact.getMarkAsDistribtuionlist() && false == parent.isSyncDistributionLists()) {
                 /*
                  * insert & delete not supported contact group (next sync cleans up the client)
@@ -475,7 +456,7 @@ public class ContactResource extends CommonResource<Contact> {
                     entry.setFolderID(dbContact.getParentFolderID());
                 }
             } else if (originalContact.isPresent()) {
-                // try to match dleo from original list 
+                // try to match dleo from original list
                 DistributionListEntryObject[] origDistList = originalContact.get().getDistributionList();
                 if (origDistList == null) {
                     continue;
@@ -630,7 +611,7 @@ public class ContactResource extends CommonResource<Contact> {
              */
             LOG.debug("{}: {}", this.getUrl(), e.getMessage());
             LOG.debug("{}: overriding next sync token for client recovery.", this.getUrl());
-            this.factory.overrideNextSyncToken();
+            factory.setOverrideNextSyncToken(parent.getFolder().getID(), "0");
         } else if (Category.CATEGORY_CONFLICT.equals(e.getCategory())) {
             throw protocolException(getUrl(), e, HttpServletResponse.SC_CONFLICT);
         } else if (Category.CATEGORY_SERVICE_DOWN.equals(e.getCategory())) {
@@ -804,7 +785,7 @@ public class ContactResource extends CommonResource<Contact> {
 
     /**
      * Gets the distribution list mode to use for serialization to vCards, based on the client's user agent.
-     * 
+     *
      * @return The distribution list mode
      */
     private DistributionListMode getDistributionListMode() {
